@@ -21,12 +21,20 @@
 
 #include "kglobalacceld.h"
 
+#ifdef Q_OS_MAC
+// kglobalaccel is defined NOGUI in the CMakeFile, but should not create its
+// KUniqueApplication instance with GUIenabled=false .
+// Undefining KDE_WITHOUT_GUI restores the pre 4.14.1 default behaviour (GUIenabled=true)
+#undef KDE_WITHOUT_GUI
+#include <CoreFoundation/CoreFoundation.h>
+#endif
+
 #include <kuniqueapplication.h>
-#include <k4aboutdata.h>
+#include <kaboutdata.h>
 #include <kcmdlineargs.h>
 #include <kcrash.h>
 #include <kde_file.h>
-#include <QDebug>
+#include <kdebug.h>
 #include <klocale.h>
 
 #include <signal.h>
@@ -45,7 +53,7 @@ static void sighandler(int /*sig*/)
 }
 
 
-extern "C" Q_DECL_EXPORT int kdemain(int argc, char **argv)
+extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
     {
     // Disable Session Management the right way (C)
     //
@@ -54,14 +62,28 @@ extern "C" Q_DECL_EXPORT int kdemain(int argc, char **argv)
     // get a hang on kglobalaccel restart (kglobalaccel tries to register with ksmserver,
     // ksmserver tries to register with kglobalaccel).
     unsetenv( "SESSION_MANAGER" );
+#ifdef Q_OS_MAC
+    CFBundleRef mainBundle = CFBundleGetMainBundle();
+    if (mainBundle) {
+        // get the application's Info Dictionary. For app bundles this would live in the bundle's Info.plist,
+        // for regular executables it is obtained in another way.
+        CFMutableDictionaryRef infoDict = (CFMutableDictionaryRef) CFBundleGetInfoDictionary(mainBundle);
+        if (infoDict) {
+            // Add or set the "LSUIElement" key with/to value "1". This can simply be a CFString.
+            CFDictionarySetValue(infoDict, CFSTR("LSUIElement"), CFSTR("1"));
+            // That's it. We're now considered as an "agent" by the window server, and thus will have
+            // neither menubar nor presence in the Dock or App Switcher.
+        }
+    }
+#endif
 
-    K4AboutData aboutdata(
+    KAboutData aboutdata(
             "kglobalaccel",
             0,
             ki18n("KDE Global Shortcuts Service"),
             "0.2",
             ki18n("KDE Global Shortcuts Service"),
-            K4AboutData::License_LGPL,
+            KAboutData::License_LGPL,
             ki18n("(C) 2007-2009  Andreas Hartmetz, Michael Jansen"));
     aboutdata.addAuthor(ki18n("Andreas Hartmetz"),ki18n("Maintainer"),"ahartmetz@gmail.com");
     aboutdata.addAuthor(ki18n("Michael Jansen"),ki18n("Maintainer"),"kde@michael-jansen.biz");
@@ -74,13 +96,13 @@ extern "C" Q_DECL_EXPORT int kdemain(int argc, char **argv)
     // check if kglobalaccel is disabled
     if (!isEnabled())
         {
-        qDebug() << "kglobalaccel is disabled!";
+        kDebug() << "kglobalaccel is disabled!";
         return 0;
         }
 
     if (!KUniqueApplication::start())
         {
-        qDebug() << "kglobalaccel is already running!";
+        kDebug() << "kglobalaccel is already running!";
         return (0);
         }
 
