@@ -75,11 +75,8 @@ DeviceAutomounter::automountDevice(Solid::Device &dev, AutomounterSettings::Auto
         Solid::StorageAccess *sa = dev.as<Solid::StorageAccess>();
         AutomounterSettings::setDeviceLastSeenMounted(dev.udi(), sa->isAccessible());
         AutomounterSettings::saveDevice(dev);
-		kDebug() << "Saving as" << dev.description();
-        if (!AutomounterSettings::automountUnknownDevices()) {
-			if(!AutomounterSettings::shouldAutomountDevice(dev.udi(), type)) {
-				return;
-			}
+        kDebug() << "Saving as" << dev.description();
+        if (AutomounterSettings::shouldAutomountDevice(dev.udi(), type)) {
             Solid::StorageVolume *sv = dev.as<Solid::StorageVolume>();
             if (!sv->isIgnored()) {
                 kDebug() << "Mounting" << dev.udi();
@@ -98,9 +95,6 @@ DeviceAutomounter::deviceAdded(const QString &udi)
     AutomounterSettings::self()->writeConfig();
     if (dev.is<Solid::StorageAccess>()) {
         Solid::StorageAccess *sa = dev.as<Solid::StorageAccess>();
-        connect(sa, SIGNAL(accessibilityChanged(bool, QString)), this, SLOT(deviceMountChanged(bool, const QString)));
+        connect(sa, SIGNAL(accessibilityChanged(bool, const QString)), this, SLOT(deviceMountChanged(bool, const QString)));
     }
 }
-
-#include "moc_DeviceAutomounter.cpp"
-#include "DeviceAutomounter.moc"
